# rpcc

**rpcc** is a Python command line tool that allows developers to easily define and work with remote procedure calls (
RPCs) compatible with the [Mercury](https://mercury-hpc.github.io/) framework.

Inspired by Google's [Protocol Buffers](https://developers.google.com/protocol-buffers), **rpcc**
allows developers to easily define RPCs using a language- and platform- neutral language, that will then be used to
generate all the necessary C/C++ boilerplate code required to actually implement them.

## Documentation

Documentation for the compiler can be found [here](https://storage.bsc.es/projects/rpcc/).
